@@ -1,4 +1,5 @@
-# 2022.5.28
+# 2022.5.30
+import json, en, requests,time,sys, traceback
 
 def topk_info(snts, docs,  topk, default_dims = {"internal_sim":0.2} ): 
 	''' info computing with topk snts, upon those long essay '''
@@ -31,16 +32,17 @@ def mkf_input(snts, docs, tokenizer, sntdic:dict={},diffmerge:bool=False):
 				for i, doc in enumerate(docs)]
 	return input #mkfs	= requests.post(f"http://172.17.0.1:7095/parser", data={"q":json.dumps(input).encode("utf-8")}).json()
 
-def localgec_todsk(essay_or_snts:str="She has ready. It are ok.", device:int=-1, asdsk:bool=True, dskhost:str='172.17.0.1:7095'
-		, debug:bool=False, gechost:str=None): #172.17.0.1:8180
-	''' essay -> dsk, with local gec model support, | pip install torch transformers| 2022.5.28 '''
-	import en, pipe, requests,time,sys, traceback
+def todsk(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, dskhost:str='gpu120.wrask.com:7095'  
+		, debug:bool= False
+		, gec_func	= lambda snts: requests.post(f"http://gpu120.wrask.com:8180/redis/getgecs", json=snts).json () 
+		, nlp_func	= lambda snt: spacy.nlp(snt) ): 
+	''' online version gec, no pipe imported, 2022.5.30 '''
 	try:
 		tims	= [ ("start", time.time(), 0)] # tag, tm, delta 
 		snts	= json.loads(essay_or_snts) if essay_or_snts.startswith("[") else en.sntbr(essay_or_snts)
-		sntdic	= requests.post(f"http://{gechost}/redis/getgecs", json=snts).json() if gechost else pipe.gecsnts(snts, device=device) #{'She has ready.': 'She is ready.', 'It are ok.': 'It is ok.'}
+		sntdic	= gec_func(snts) #{'She has ready.': 'She is ready.', 'It are ok.': 'It is ok.'}
 		if debug : tims.append( ("gec", time.time(), round(time.time() - tims[-1][1],2))  )
-		docs	= [ spacy.nlp(snt) for snt in snts ] 
+		docs	= [ nlp_func(snt) for snt in snts ] 
 		if debug : tims.append( ("nlp", time.time(), round(time.time() - tims[-1][1],2))  )
 		input	= mkf_input(snts, docs, spacy.nlp.tokenizer, sntdic)
 		dsk		= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps({"snts":input, "rid":"10"} if asdsk else input).encode("utf-8")}).json()
@@ -48,13 +50,14 @@ def localgec_todsk(essay_or_snts:str="She has ready. It are ok.", device:int=-1,
 		if debug and isinstance(dsk, dict) and 'info' in dsk : dsk['info']['tim'] = tims #[('start', 1653811771.030599, 0), ('gec', 1653811776.2294545, 5.2), ('nlp', 1653811776.2439919, 0.01), ('dsk', 1653811776.275237, 0.03)]
 		return dsk  #docker run -d --restart=always --name dsk17095 -v /data/dct:/dct -p 7095:7095 wrask/gec:dsk8 java -Xmx4096m -jar pigai_engine8.jar --database-no-encrypt --server-addr dsk.wrask.com --server-port 7095  --database-type sqlite --sqlite-file dct/sqlite/pigai_spss.sqlite3 --thread-num 2 --gec-snts-address http://wrask.com:33000/gec/essay_or_snts
 	except Exception as ex: 
-		print(">>localgec_todsk Ex:", ex, "\t|", essay_or_snts)
+		print(">>todsk Ex:", ex, "\t|", essay_or_snts)
 		exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 		traceback.print_tb(exc_traceback_obj)
 
-def todsk(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, dskhost:str='gpu120.wrask.com:7095', gechost:str="gpu120.wrask.com:8180"): 
-	''' online version gec, 2022.5.29 '''
-	return localgec_todsk(essay_or_snts, asdak = asdsk, dskhost=dskhost, gechost=gechost) 
+def localgec_todsk(essay_or_snts:str="She has ready. It are ok.", device:int=-1, asdsk:bool=True, dskhost:str='172.17.0.1:7095', debug:bool=False): 
+	''' essay -> dsk, with local gec model support, |  2022.5.28 '''
+	import pipe #pip install torch transformers|
+	return todsk(essay_or_snts, asdsk=asdsk, dskhost=dskhost, debug=debug, gec_func = lambda snts: pipe.gecsnts(snts, device=device))
 
 def init_dskmkf_table(cursor):
 	cursor.execute('''CREATE TABLE if not exists `dsk` (
@@ -88,7 +91,7 @@ def init_dskmkf_table(cursor):
   FULLTEXT KEY `sntkps` (`snt`,`kps`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci''')
 
-import hashlib,json,en
+import hashlib
 md5snt	= lambda text: hashlib.md5(text.encode("utf-8")).hexdigest()
 
 doc_tok	= lambda doc:  [ {'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_} for t in doc]
@@ -122,7 +125,7 @@ def submit_dskmkf(dsk, cursor):
 			json.dumps(doc_tok(doc)), json.dumps(doc_chunk(doc)), json.dumps(meta), json.dumps(fds), spacy.tobs(doc)  ) 	)
 
 if __name__ == '__main__':
-	res = localgec_todsk(dskhost="gpu120.wrask.com:7095", gechost="gpu120.wrask.com:8180", debug=True)
+	res = todsk(dskhost="gpu120.wrask.com:7095", debug=True)
 	print ( res ) 
 	print ( res['info']['tim'])
 
