@@ -1,9 +1,9 @@
-# 22-5-28  
+# 22-5-29
 import json, sys, time, fire,traceback, requests,os
 import dsk,util
 
 class Dsk(object):
-	def __init__(self, dskhost:str='172.17.0.1:7095'): 
+	def __init__(self, dskhost:str='gpu120.wrask.com:7095'):  #172.17.0.1:7095
 		self.dskhost = dskhost
 
 	def json_to_dskmkf(self,infile, host='192.168.121.3',port=3306,user='root',password='cikuutest!',db='dskmkf', load=True):  
@@ -32,13 +32,13 @@ class Dsk(object):
 		''' test localgec todsk '''
 		print (dsk.localgec_todsk(essay, dskhost=self.dskhost))
 
-	def localgec(self,device:int=-1, topk:int=7): 
+	def localgec(self,device:int=-1, topk:int=7, gechost:str=None): 
 		''' test localgec todsk, perf '''
 		from dic.essays import essays 
 		for i in range(topk): 
 			essay = essays[i].get('essay','') 
 			start = time.time() 
-			res	  = dsk.localgec_todsk(essay, device=device, dskhost=self.dskhost)
+			res	  = dsk.localgec_todsk(essay, device=device, dskhost=self.dskhost, gechost=gechost)
 			print (f"No. {i}, timing={time.time()-start}, len-essay={len(essay)}, \tscore=", res['info']['final_score'], flush=True) 
 
 class util(object):
