@@ -226,7 +226,8 @@ class util(object):
 		uvicorn.run(app, host='0.0.0.0', port=port)
 
 	def load(self, infile, idxname) : 
-		''' load text file into index  '''
+		''' load text file into index, 
+		find . -name "*.txt" -exec python -m so.corpusly load {} inau \;   '''
 		with open(infile, 'r',encoding='utf-8') as fp:
 			indexdoc({"body": fp.read(), 'filename': infile}, idxname = idxname) 
 		print ("finished:", infile ) 
